===================
Main user functions
===================

.. currentmodule:: sedfitter

Fitting
-------

.. autofunction:: sedfitter.fit
.. autofunction:: sedfitter.filter_output

Plotting
--------

.. autofunction:: sedfitter.plot
.. autofunction:: sedfitter.plot_params_1d
.. autofunction:: sedfitter.plot_params_2d

Extracting values
-----------------

.. autofunction:: sedfitter.write_parameters
.. autofunction:: sedfitter.write_parameter_ranges

Classes
-------

.. autoclass:: sedfitter.extinction.Extinction
   :members:

.. autoclass:: sedfitter.filter.Filter
   :members:

.. autoclass:: sedfitter.convolved_fluxes.ConvolvedFluxes
   :members:
